@@ -565,7 +565,7 @@ class DemodData(models.Model):
         with open(self.payload_demod.path, 'rb') as file_path:
             try:
                 Image.open(file_path)
-            except (IOError, TypeError):
+            except (IOError, TypeError, ValueError):
                 return False
             else:
                 return True
